Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DoChainReplace ¶
DoChainReplace does the replace operation with reader chaining, which is faster but more resource intensive.
func DoSequentialReplace ¶
DoSequentialReplace does the replace operation without reader chaining, which is slower but less resource intensive.
Types ¶
type Replacer ¶
type Replacer struct {
Config *replacerConfig
}
Replacer contains all of the methods needed to properly execute replace operations
func NewReplacer ¶
NewReplacer returns a new *Replacer type
func (*Replacer) NewMapping ¶
NewMapping maps a new oldString:newString []byte entry
func (*Replacer) NewStringMapping ¶
NewStringMapping maps a new oldString:newString string entry
func (*Replacer) Replace ¶
Replace does the replace operation with a concurrent (sequential) reader --> tmpfile model
func (*Replacer) ReplaceChained ¶
ReplaceChained does the replace operation with a chained reader model
Click to show internal directories.
Click to hide internal directories.